@@ -19,7 +19,7 @@ require 'spec_helper'
 describe 'tripleo::profile::base::horizon' do
   shared_examples_for 'tripleo::profile::base::horizon' do
     let(:pre_condition) do
-      "class { '::tripleo::profile::base::aodh': step => #{params[:step]}, oslomsg_rpc_hosts => ['localhost.localdomain'] }"
+      "class { 'tripleo::profile::base::aodh': step => #{params[:step]}, oslomsg_rpc_hosts => ['localhost.localdomain'] }"
     end
 
     context 'with step less than 3' do
